@@ -5,7 +5,9 @@
 related <- function(x) {
   ans <- NULL
   while(nrow(x)>0) {
-   xx <- plyr::arrange(plyr::count(c(x$ID1, x$ID2)), -"freq")
+   xx <- plyr::count(c(x$ID1, x$ID2))
+   o <- order(xx$freq, decreasing = TRUE)
+   xx <- xx[o,]
    rm.xx <- xx$x[1]
    x <- subset(x, x$ID1 != rm.xx & x$ID2 != rm.xx)
    ans <- c(as.character(rm.xx), ans)
